from distutils.core import setup
setup(
  name = 'culqipy',
  packages = ['culqipy'],
  version = '0.1.4',
  description = 'Biblioteca de Culqi en Python',
  author = 'Willy Aguirre - Culqi Team',
  author_email = 'willy.aguirre@culqi.com',
  url = 'https://github.com/culqi/culqi-python',
  download_url = 'https://github.com/culqi/culqi-python/tarball/0.1.3',
  keywords = ['api', 'json', 'culqi', 'apiv2'],
  classifiers = [],
)
